using Tiger.Communication.Messages.Interfaces;
using Tiger.Communication.Messages.Outgoing.Avatar;
using Tiger.Communication.Messages.Types;
using Tiger.Game.Figuredata;
using Tiger.Game.Habbos;
using Tiger.Networking.Game.Sessions;
using Tiger.Storage;

namespace Tiger.Communication.Messages.Incoming.Register;

public class UpdateFigureDataMessageEvent : IMessageEvent
{
    private readonly IGameSessionManager _gameSessionManager;
    private readonly IFigureDataManager _figureDataManager;
    private readonly IRepository<Habbo> _habboRepository;

    public UpdateFigureDataMessageEvent(IGameSessionManager gameSessionManager, IFigureDataManager figureDataManager, IRepository<Habbo> habboRepository)
    {
        _gameSessionManager = gameSessionManager;
        _figureDataManager = figureDataManager;
        _habboRepository = habboRepository;
    }

    public IncomingHeaders Header => IncomingHeaders.UpdateFigureDataEvent;
    public async Task HandleAsync(GameSession gameSession, ClientMessage request)
    {
        if (gameSession.Habbo == null)
        {
            await _gameSessionManager.CloseAsync("Not logged in", gameSession);
            return;
        }
        
        var gender = request.ReadString()?.ToUpper();
        var figure = request.ReadString();

        if (gender is null || figure is null || (gender != "M" && gender != "F") /*||
            !_figureDataManager.ValidateFigure(figure, gender, gameSession.Habbo)*/)
        {
            return;
        }

        gameSession.Habbo.Figure = figure;
        gameSession.Habbo.Gender = gender;
        _habboRepository.SaveAsync(gameSession.Habbo);

        await gameSession.SendComposerAsync(new FigureUpdateComposer(figure, gender));
    }
}